==> haskell-digits-0.3.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-7KeAJBIeFFs3iQbkyHRIg6
key:                  digits-0.3.2-7KeAJBIeFFs3iQbkyHRIg6
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  f88bf42bc7ec3555e3c055bd427020fb
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-7KeAJBIeFFs3iQbkyHRIg6
depends:
    QuickCheck-2.15.0.1-4mIWiyi0MCz4O9NEuBQDps base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digits-0.3.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-KiKMkFspWDcBuVCeD9zBBX
key:                  digits-0.3.2-KiKMkFspWDcBuVCeD9zBBX
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  ba14a87643efea2da14a6e34e07233f8
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-KiKMkFspWDcBuVCeD9zBBX
depends:
    QuickCheck-2.15.0.1-LaRIQHiwv8U7w9VIoXbmQQ base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
